@@ -1,6 +1,6 @@
 package Tie::Array::DBD;
 
-our $VERSION = "0.16";
+our $VERSION = "0.17";
 
 use strict;
 use warnings;
@@ -33,6 +33,13 @@ my %DB = (
 	clear	=> "truncate table",
 	autoc	=> 0,
 	},
+    MariaDB	=> {
+	temp	=> "temporary",
+	t_key	=> "bigint not null primary key",
+	t_val	=> "blob",
+	clear	=> "truncate table",
+	autoc	=> 0,
+	},
     mysql	=> {
 	temp	=> "temporary",
 	t_key	=> "bigint not null primary key",
@@ -56,14 +63,13 @@ my %DB = (
 	},
     Firebird	=> {
 	temp	=> "",
-	t_key	=> "integer not null primary key",
+	t_key	=> "integer primary key",
 	t_val	=> "varchar (8192)",
 	clear	=> "delete from",
 	},
     );
 
-sub _create_table
-{
+sub _create_table {
     my ($cnf, $tmp) = @_;
     $cnf->{tmp} = $tmp;
 
@@ -91,8 +97,7 @@ sub _create_table
     $dbt eq "Unify" and $dbh->commit;
     } # create table
 
-sub TIEARRAY
-{
+sub TIEARRAY {
     my $pkg = shift;
     my $usg = qq{usage: tie \@a, "$pkg", \$dbh [, { tbl => "tbl", key => "f_key", fld => "f_value" }];};
     my $dsn = shift or croak $usg;
@@ -176,8 +181,7 @@ sub TIEARRAY
     bless $h, $pkg;
     } # TIEARRAY
 
-sub _stream
-{
+sub _stream {
     my ($self, $val) = @_;
     defined $val or return undef;
     $self->{str} or return $val;
@@ -186,8 +190,7 @@ sub _stream
     return $val;
     } # _stream
 
-sub _unstream
-{
+sub _unstream {
     my ($self, $val) = @_;
     defined $val or return undef;
     $self->{str} or return $val;
@@ -196,8 +199,7 @@ sub _unstream
     return $val;
     } # _unstream
 
-sub _setmax
-{
+sub _setmax {
     my $self = shift;
     my $sth = $self->{dbh}->prepare ("select max($self->{f_k}) from $self->{tbl}");
     $sth->execute;
@@ -210,8 +212,7 @@ sub _setmax
     $self->{max};
     } # _setmax
 
-sub STORE
-{
+sub STORE {
     my ($self, $key, $value) = @_;
     my $v = $self->_stream ($value);
     $self->EXISTS ($key)
@@ -220,8 +221,7 @@ sub STORE
     $key > $self->{max} and $self->{max} = $key;
     } # STORE
 
-sub DELETE
-{
+sub DELETE {
     my ($self, $key) = @_;
     $self->{sel}->execute ($key);
     my $r = $self->{sel}->fetch or return;
@@ -230,31 +230,27 @@ sub DELETE
     $self->_unstream ($r->[0]);
     } # DELETE
 
-sub STORESIZE
-{
+sub STORESIZE {
     my ($self, $size) = @_; # $size = $# + 1
     $size--;
     $self->{dbh}->do ("delete from $self->{tbl} where $self->{f_k} > $size");
     $self->{max} = $size;
     } # STORESIZE
 
-sub CLEAR
-{
+sub CLEAR {
     my $self = shift;
     $self->{dbh}->do ("$DB{$self->{dbt}}{clear} $self->{tbl}");
     $self->{max} = -1;
     } # CLEAR
 
-sub EXISTS
-{
+sub EXISTS {
     my ($self, $key) = @_;
     $key <= $self->{max} or return 0;
     $self->{sel}->execute ($key);
     return $self->{sel}->fetch ? 1 : 0;
     } # EXISTS
 
-sub FETCH
-{
+sub FETCH {
     my ($self, $key) = @_;
     $key <= $self->{max} or return undef;
     $self->{sel}->execute ($key);
@@ -262,8 +258,7 @@ sub FETCH
     $self->_unstream ($r->[0]);
     } # STORE
 
-sub PUSH
-{
+sub PUSH {
     my ($self, @val) = @_;
     for (@val) {
 	$self->STORE (++$self->{max}, $_);
@@ -271,15 +266,13 @@ sub PUSH
     return $self->FETCHSIZE;
     } # PUSH
 
-sub POP
-{
+sub POP {
     my $self = shift;
     $self->{max} >= 0 or return;
     $self->DELETE ($self->{max});
     } # POP
 
-sub SHIFT
-{
+sub SHIFT {
     my $self = shift;
     my $val  = $self->DELETE (0);
     $self->{uky}->execute ($_ - 1, $_) for 1 .. $self->{max};
@@ -287,8 +280,7 @@ sub SHIFT
     return $val;
     } # SHIFT
 
-sub UNSHIFT
-{
+sub UNSHIFT {
     my ($self, @val) = @_;
     @val or return;
     my $incr = scalar @val;
@@ -320,8 +312,7 @@ sub UNSHIFT
 #   If OFFSET is past the end of the array, Perl issues a warning, and splices
 #     at the end of the array.
 
-sub SPLICE
-{
+sub SPLICE {
     my $nargs = $#_;
     my ($self, $off, $len, @new, @val) = @_;
 
@@ -378,40 +369,34 @@ sub SPLICE
     return wantarray ? @val : $val[-1];
     } # SPLICE
 
-sub FIRSTKEY
-{
+sub FIRSTKEY {
     my $self = shift;
     $self->{max} >= 0 or return;
     $self->{min} = 0;
     } # FIRSTKEY
 
-sub NEXTKEY
-{
+sub NEXTKEY {
     my $self = shift;
     exists $self->{min} && $self->{min} < $self->{max} and return ++$self->{min};
     delete $self->{min};
     return;
     } # FIRSTKEY
 
-sub FETCHSIZE
-{
+sub FETCHSIZE {
     my $self = shift;
     return $self->{max} + 1;
     } # FETCHSIZE
 
-sub EXTEND
-{
+sub EXTEND {
     # no-op
     } # EXTEND
 
-sub drop
-{
+sub drop {
     my $self = shift;
     $self->{tmp} = 1;
     } # drop
 
-sub _dump_table
-{
+sub _dump_table {
     my $self = shift;
     my $sth = $self->{dbh}->prepare ("select $self->{f_k}, $self->{f_v} from $self->{tbl} order by $self->{f_k}");
     $sth->execute;
@@ -421,8 +406,7 @@ sub _dump_table
 	}
     } # _dump_table
 
-sub DESTROY
-{
+sub DESTROY {
     my $self = shift;
     my $dbh = $self->{dbh} or return;
     for (qw( sel ins upd del cnt ctv uky )) {
@@ -506,17 +490,18 @@ all by itself, but uses the connection provided in the handle.
 
 If the first argument is a scalar, it is used as DSN for DBI->connect ().
 
-Supported DBD drivers include DBD::Pg, DBD::SQLite, DBD::CSV, DBD::mysql,
-DBD::Oracle, DBD::Unify, and DBD::Firebird.  Note that due to limitations
-they won't all perform equally well. Firebird is not tested anymore.
+Supported DBD drivers include DBD::Pg, DBD::SQLite, DBD::CSV, DBD::MariaDB,
+DBD::mysql, DBD::Oracle, DBD::Unify, and DBD::Firebird.  Note that due to
+limitations they won't all perform equally well. Firebird is not tested
+anymore.
 
 DBD::Pg and DBD::SQLite have an unexpected great performance when server
 is the local system. DBD::SQLite is even almost as fast as DB_File.
 
 The current implementation appears to be extremely slow for CSV, as
-expected, mysql, and Unify. For Unify and mysql that is because these do
-not allow indexing on the key field so they cannot be set to be primary
-key.
+expected, mariadb/mysql, and Unify. For Unify and mariadb/mysql that is
+because these do not allow indexing on the key field so they cannot be
+set to be primary key.
 
 When using DBD::CSV with Text::CSV_XS version 1.02 or newer, it might be
 wise to disable utf8 encoding (only supported as of DBD::CSV-0.48):
@@ -695,7 +680,7 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2015 H.Merijn Brand
+Copyright (C) 2010-2018 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
